@@ -1,11 +1,22 @@
 from django.conf import settings as default_settings
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.importlib import import_module
+try:
+    from importlib import import_module
+except ImportError:  # PY26 # pragma: no cover
+    from functools import partial
+    import_module = partial(__import__, fromlist=[''])
 
 
+# DEPRECATED: To be removed in Backends 2.0
+import warnings
 DID_NOT_HANDLE = object()
 
 
+class BackendDidNotHandle(Exception):
+    """The backend did not perform the expected action"""
+    pass
+
+
 class Proxy(object):
     def __init__(self, possibles, attr):
         self.attr = attr
@@ -13,8 +24,16 @@ class Proxy(object):
 
     def __call__(self, *args, **kwargs):
         for possible in self.possibles:
-            ret = getattr(possible, self.attr, None)(*args, **kwargs)
+            try:
+                ret = getattr(possible, self.attr, None)(*args, **kwargs)
+            except BackendDidNotHandle:
+                continue
+            # DEPRECATED: To be removed in Backends 2.0
             if ret is DID_NOT_HANDLE:
+                errmsg = ("DID_NOT_HANDLE is deprecated and will be removed in "
+                          "armstrong.utils.backends 2.0. "
+                          "Use BackendDidNotHandle.")
+                warnings.warn(errmsg, DeprecationWarning, stacklevel=2)
                 continue
             return ret
 
@@ -32,9 +51,7 @@ class GenericBackend(object):
 
     def __init__(self, key, settings=None, defaults=None):
         self.key = key
-        if not settings:
-            settings = default_settings
-        self.settings = settings
+        self.settings = settings or default_settings
         self.defaults = defaults
 
     @property
@@ -57,5 +74,5 @@ class GenericBackend(object):
         if type(self.configured_backend) is str:
             return to_backend(self.configured_backend)(*args, **kwargs)
         else:
-            return self.proxy_class(*[to_backend(a)(*args, **kwargs) for a in
-                self.configured_backend])
+            return self.proxy_class(*[to_backend(a)(*args, **kwargs)
+                                      for a in self.configured_backend])
